@@ -114,3 +114,16 @@ class C51(Agent):
         log_dist = torch.log(torch.clamp(dist, min=self.eps))
         log_target_dist = torch.log(torch.clamp(target_dist, min=self.eps))
         return (target_dist * (log_target_dist - log_dist)).sum(dim=-1)
+
+
+class C51TestAgent(Agent):
+    def __init__(self, q_dist, n_actions, exploration=0.):
+        self.q_dist = q_dist
+        self.n_actions = n_actions
+        self.exploration = exploration
+
+    def act(self, state):
+        if np.random.rand() < self.exploration:
+            return np.random.randint(0, self.n_actions)
+        q_values = (self.q_dist(state) * self.q_dist.atoms).sum(dim=-1)
+        return torch.argmax(q_values, dim=-1)
