@@ -2,6 +2,7 @@ import gym
 import torch
 from all.core import State
 from ._environment import Environment
+from .duplicate_env import DuplicateEnvironment
 import cloudpickle
 gym.logger.set_level(40)
 
@@ -66,7 +67,7 @@ class GymEnvironment(Environment):
         self._env.seed(seed)
 
     def duplicate(self, n):
-        return [GymEnvironment(cloudpickle.loads(cloudpickle.dumps(self._env)), device=self.device) for _ in range(n)]
+        return DuplicateEnvironment([GymEnvironment(cloudpickle.loads(cloudpickle.dumps(self._env)), device=self.device) for _ in range(n)])
 
     @property
     def state_space(self):
