@@ -2,19 +2,22 @@ from .run_experiment import run_experiment
 from .experiment import Experiment
 from .single_env_experiment import SingleEnvExperiment
 from .parallel_env_experiment import ParallelEnvExperiment
+from .multiagent_env_experiment import MultiagentEnvExperiment
 from .writer import ExperimentWriter
+from .writer import CometWriter
 from .plots import plot_returns_100
 from .slurm import SlurmExperiment
-from .watch import GreedyAgent, watch, load_and_watch
+from .watch import watch, load_and_watch
 
 __all__ = [
     "run_experiment",
     "Experiment",
     "SingleEnvExperiment",
     "ParallelEnvExperiment",
+    "MultiagentEnvExperiment",
     "SlurmExperiment",
-    "GreedyAgent",
     "ExperimentWriter",
+    "CometWriter",
     "watch",
     "load_and_watch",
 ]
