@@ -1,5 +1,6 @@
 from .single_env_experiment import SingleEnvExperiment
 from .parallel_env_experiment import ParallelEnvExperiment
+from all.presets import ParallelPreset
 
 
 def run_experiment(
@@ -10,7 +11,8 @@ def run_experiment(
         quiet=False,
         render=False,
         test_episodes=100,
-        write_loss=True
+        write_loss=True,
+        writer="tensorboard"
 ):
     if not isinstance(agents, list):
         agents = [agents]
@@ -19,25 +21,26 @@ def run_experiment(
         envs = [envs]
 
     for env in envs:
-        for agent in agents:
-            make_experiment = get_experiment_type(agent)
+        for preset_builder in agents:
+            preset = preset_builder.env(env).build()
+            make_experiment = get_experiment_type(preset)
             experiment = make_experiment(
-                agent,
+                preset,
                 env,
+                train_steps=frames,
                 logdir=logdir,
                 quiet=quiet,
                 render=render,
-                write_loss=write_loss
+                write_loss=write_loss,
+                writer=writer
             )
             experiment.train(frames=frames)
+            experiment.save()
             experiment.test(episodes=test_episodes)
+            experiment.close()
 
 
-def get_experiment_type(agent):
-    if is_parallel_env_agent(agent):
+def get_experiment_type(preset):
+    if isinstance(preset, ParallelPreset):
         return ParallelEnvExperiment
     return SingleEnvExperiment
-
-
-def is_parallel_env_agent(agent):
-    return isinstance(agent, tuple)
