@@ -1,8 +1,9 @@
 import os
 import unittest
 import torch
-from all.environments import AtariEnvironment
+from all.environments import AtariEnvironment, DuplicateEnvironment
 from all.logging import DummyWriter
+from all.presets import Preset, ParallelPreset
 from all.presets.atari import (
     a2c,
     c51,
@@ -21,6 +22,8 @@ class TestAtariPresets(unittest.TestCase):
     def setUp(self):
         self.env = AtariEnvironment('Breakout')
         self.env.reset()
+        self.parallel_env = DuplicateEnvironment([AtariEnvironment('Breakout'), AtariEnvironment('Breakout')])
+        self.parallel_env.reset()
 
     def tearDown(self):
         if os.path.exists('test_preset.pt'):
@@ -58,7 +61,12 @@ class TestAtariPresets(unittest.TestCase):
 
     def validate_preset(self, builder):
         preset = builder.device('cpu').env(self.env).build()
-        # normal agent
+        if isinstance(preset, ParallelPreset):
+            return self.validate_parallel_preset(preset)
+        return self.validate_standard_preset(preset)
+
+    def validate_standard_preset(self, preset):
+        # train agent
         agent = preset.agent(writer=DummyWriter(), train_steps=100000)
         agent.act(self.env.state)
         # test agent
@@ -70,6 +78,22 @@ class TestAtariPresets(unittest.TestCase):
         test_agent = preset.test_agent()
         test_agent.act(self.env.state)
 
+    def validate_parallel_preset(self, preset):
+        # train agent
+        agent = preset.agent(writer=DummyWriter(), train_steps=100000)
+        agent.act(self.parallel_env.state_array)
+        # test agent
+        test_agent = preset.test_agent()
+        test_agent.act(self.env.state)
+        # parallel test_agent
+        parallel_test_agent = preset.test_agent()
+        parallel_test_agent.act(self.parallel_env.state_array)
+        # test save/load
+        preset.save('test_preset.pt')
+        preset = torch.load('test_preset.pt')
+        test_agent = preset.test_agent()
+        test_agent.act(self.env.state)
+
 
 if __name__ == "__main__":
     unittest.main()
